searchData={"items":[{"type":"module","title":"PhoenixBetterTable","doc":"A table component whose contents can be sorted by clicking on each header.","ref":"PhoenixBetterTable.html"},{"type":"module","title":"Assigns - PhoenixBetterTable","doc":"* `:meta` - a map containing a `:headers` key:\n    * `headers:` - a list of maps, each representing a header in the table:\n        * `:id` - the column's id, which will be used as the key for rendering and sorting\n        * `:label` - the column's label (optional)\n        * `:filter` - a boolean indicating whether the column is filterable (optional, default true), or a 1-arity function that returns text to be filtered (default `to_string/1`)\n        * `:sort` - either a boolean indicating whether the column is sortable (optional, default true), or a compare/2 function that returns true if the first argument precedes or is in the same place as the second one.\n        * `:render` - an optional component that renders cells in the column\n* `:rows` - a list of maps, each representing a row in the table\n* `:sort` - a tuple containing the column id and the sort order (`:asc` or `:desc`) (optional)\n* `:class` - a string containing additional classes to be added to the table (optional)\n* `:body_class` - a string containing additional classes to be added to the table body (optional)\n* `:header_class` - a string containing additional classes to be added to the table header (optional)","ref":"PhoenixBetterTable.html#module-assigns"},{"type":"module","title":"Slots - PhoenixBetterTable","doc":"* `:filter_control` - an optional slot that takes a single argument, a tuple of `{active?, id, myself}`. The interactive element should\nset `phx-click=\"filter_toggle\"`, `phx-value-header={id}`, and `phx-target={myself}` for the event to be routed correctly.\n* `:sort_control` - an optional slot that takes a single argument, a tuple of `{direction, id, myself}`. See above.","ref":"PhoenixBetterTable.html#module-slots"},{"type":"function","title":"PhoenixBetterTable.render/1","doc":"","ref":"PhoenixBetterTable.html#render/1"},{"type":"extras","title":"PhoenixBetterTable","doc":"# PhoenixBetterTable\n\nPhoenixBetterTable is a Phoenix Live Component that presents a filterable and sortable table component given table metadata and rows.","ref":"readme.html"},{"type":"extras","title":"Why? - PhoenixBetterTable","doc":"It is designed to fill the space between ` ` and fully featured data tables backed by Ecto, such as those in [flop_phoenix](https://hex.pm/packages/flop_phoenix).","ref":"readme.html#why"},{"type":"extras","title":"Features - PhoenixBetterTable","doc":"- (optionally) sortable columns\n- (optionally) filterable columns\n- (optionally) add custom classes to the table header\n- (optionally) add custom classes to the table body\n- custom render functions for each column","ref":"readme.html#features"},{"type":"extras","title":"Usage - PhoenixBetterTable","doc":"```elixir\n<.live_component\n    id=\"123\"\n    module={PhoenixBetterTable}\n    rows={[%{text: \"Hello\", number: 123}, %{text: \"World\", number: 456}]}\n    meta={%{headers: [%{id: :text, label: \"string\", sort: false}, %{id: :number}]}} />\n```\n\nproduces a table with two columns (\"Hello\" and \"World\"), one sortable column (\"World), and filtering by column contents:\n\n \n\n#","ref":"readme.html#usage"},{"type":"extras","title":"Custom render functions - PhoenixBetterTable","doc":"Suppose you have a column with an action button you want to render. You can define a custom render function for that column:\n\n```elixir\n  def render_button(assigns) do\n    ~H\"\"\"\n       <%= @value %> \n    \"\"\"\n  end\n```\n\nand pass it to the `meta` map:\n\n```elixir\n<.live_component \n  id=\"123\" \n  module={PhoenixBetterTable} \n  rows={[%{action: \"Hello\", number: 123}, %{action: \"World\", number: 456}]} \n  meta={%{headers: [%{id: :action, label: \"Action\", sort: false, render: &render_button/1}, %{id: :number}]}} />\n```","ref":"readme.html#custom-render-functions"},{"type":"extras","title":"Installation - PhoenixBetterTable","doc":"The package can be installed by adding `phoenix_better_table` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:phoenix_better_table, \"~> 0.5.0\"}\n  ]\nend\n```\n\nThe docs can be found at  .","ref":"readme.html#installation"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,49,46,50]}}